@@ -39,6 +39,17 @@ public:
 
     /** Create a new JSON-LD object of type @p typeName. */
     Q_INVOKABLE QJSValue newObject(const QString &typeName) const;
+
+    /** Convenience method that generates a full FlightReservation JS object.
+     *  This can be used by extractor scripts to fill in the extracted information.
+     */
+    Q_INVOKABLE QJSValue newFlightReservation() const;
+    /** Convenience method that generates a full LodgingReservation JS object.
+     *  This can be used by extractor scripts to fill in the extracted information.
+     */
+    Q_INVOKABLE QJSValue newLodgingReservation() const;
+    // TODO add the same for other reservation types
+
     /** Convert a date/time string to a date/time value.
      *  @param dtStr The input string containing a date/time value.
      *  @param format The format of the input string. Same format specification as
